@@ -6,7 +6,7 @@ import threading
 import time
 import warnings
 from functools import wraps
-from typing import List, Union, Callable, Tuple
+from typing import List, Union, Callable, Tuple, Optional
 
 from .basic import Action, ActionList
 from ..mixin import Status, Configuration, InstanceRegistry, DumpableList, make_iterable_serializable, make_mapping_serializable, serializable_cast
@@ -26,6 +26,7 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
                  condition: Union[Tuple[object, str], Callable] = None,
                  aliases: List[str] = None,
                  use_unique_action: bool = False,
+                 parent_identifier_override: str = None,
                  **kwargs,
                  ):
         """
@@ -44,14 +45,17 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
         :param kwargs: keyword arguments for the action
         :param aliases: list of aliases which refer to the configured action instance
         :param use_unique_action: whether to register action as a unique action (usually in cases where actions have
-            stateful instance dependencies and there may be more than one action of the same name registered)
+            stateful instance dependencies and there may be more than one action of the same name registered).
+        :param parent_identifier_override: Optional override for the parent identifier used for unique configured action
+            generation.
         """
         # todo ability to retrieve the executions of a given configured action
         InstanceRegistry.__init__(self)
         self._action: Action = None
         self._config_name: str = None
         self._next_action = None
-        self._use_unique_action = use_unique_action
+        self._use_unique_action = True if parent_identifier_override is not None else use_unique_action
+        self.parent_identifier_override: Optional[str] = parent_identifier_override
         # list of aliases for the configuration
         if aliases is None:
             aliases = []  # prevent mutation
@@ -106,9 +110,17 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
     @action.setter
     def action(self, value: Union[Callable, Action, str]):
         if value is not None:
+            # retrieve appropriate parent identifier
+            if self._use_unique_action is True:
+                if self.parent_identifier_override is not None:
+                    parent_id = self.parent_identifier_override
+                else:
+                    parent_id = self._uuid
+            else:
+                parent_id = None
             self._action = Action.register_action(
                 value,
-                self._uuid if self._use_unique_action is True else None
+                parent_identifier=parent_id,
             )
 
     @property
@@ -222,6 +234,37 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
             return True  # match alias
         return False
 
+    def match_name_and_parent(self,
+                              name: Union[Callable, str, 'ConfiguredAction'],
+                              parent_identifier: str = None,
+                              ) -> bool:
+        """
+        Compares the provided name and parent identifier against the Configured Action instance (in effect an
+        equality check)
+
+        :param name: name to use
+        :param parent_identifier: parent identifier (optional)
+        :return: whether the name and parent identifier match
+        """
+        name_match = False
+
+        if isinstance(name, ConfiguredAction) and name is self:
+            return True
+        if callable(name) is True and name == self.action.action:  # todo figure out why "is" doesn't work here
+            name_match = True
+        elif type(name) is str and self.action.name == name:
+            name_match = True
+        elif self.name == name:
+            name_match = True
+        # if there is a name match and the parent identifier was specified, ensure match
+        if name_match and parent_identifier is not None:
+            if self.action.parent_identifier == parent_identifier:
+                return True
+            return False
+        elif name_match and self.parent_identifier_override is not None:
+            return False  # parent identifier did not match
+        return name_match
+
     @classmethod
     def get_configuration_by_name(cls, configuration_name: str) -> 'ConfiguredAction':
         """
@@ -264,13 +307,20 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
         ]
 
     @classmethod
-    def remove_configuration_from_registry(cls, configuration: Union[str, 'ConfiguredAction']):
+    def remove_configuration_from_registry(cls,
+                                           configuration: Union[str, 'ConfiguredAction'],
+                                           parent_identifier: str = None,
+                                           ):
         """
         Removes the specified configuration from the configuration registry
 
         :param configuration: name or instance of the configuration
+        :param parent_identifier: optional parent identifier
         """
-        raise NotImplementedError('this method is not currently implemented')
+        for inst in cls.class_registry:
+            if inst.match_name_and_parent(name=configuration, parent_identifier=parent_identifier):
+                cls.class_registry.remove(inst)
+                del inst  # removes the instance
 
     @classmethod
     def ensure_configuration(cls,
@@ -354,26 +404,60 @@ class ConfiguredAction(InstanceRegistry, Configuration, Status):
         })
         return dct
 
+    @classmethod
+    def class_instance_by_id(cls, identifier: str, parent_id: Union[str] = None) -> 'ConfiguredAction':
+        """
+        Retrieves the instance of the current class by UUID
+
+        :param identifier: unique identifier
+        :raises NameError: if no matching instance could be found
+        :param parent_id: optional specification of parent ID to retrieve instances specifically registered to
+            a parent identifier.
+        :return: registered class instance
+        """
+        try:
+            for inst in cls._registry[cls.__name__]:
+                inst: ConfiguredAction
+                if parent_id is None and cls._match_instance_key(inst, identifier) is True:
+                    return inst
+                elif inst.match_name_and_parent(identifier, parent_identifier=parent_id) is True:
+                    return inst
+        except KeyError:  # if there are no registered instances of the class, raise a consistent error
+            pass
+        raise NameError(f'the uuid "{identifier}" could not be found in the registry of {cls.__name__}')
+
 
 class ConfiguredActionList(ActionList, DumpableList):
-    def __init__(self, *actions: Union[Action, ConfiguredAction]):
+    def __init__(self,
+                 *actions: Union[Action, ConfiguredAction],
+                 use_unique_action: bool = False,
+                 parent_identifier_override: str = None,
+                 ):
         """
         A manager for a list of Configured Actions.
 
         :param actions: actions to sequence
+        :param use_unique_action: whether to use unique actions for any action added to this list
+        :param parent_identifier_override: optional override for parent identifier used in ConfiguredAction
+            unique identifier association.
         """
         self._action_list: List[ConfiguredAction] = []
+        self.use_unique_action: bool = True if parent_identifier_override is not None else use_unique_action
+        self.parent_identifier_override: Optional[str] = None
         super().__init__(*actions)
 
-    @staticmethod
-    def _ensure_type(action: Union[str, Action, ConfiguredAction]) -> ConfiguredAction:
+    def _ensure_type(self, action: Union[str, Action, ConfiguredAction]) -> ConfiguredAction:
         """Ensures that the provided action is of the correct type for the list"""
         if isinstance(action, ConfiguredAction):
             return action
         elif type(action) is str:
             return ConfiguredAction.class_instance_by_id(action)
         else:
-            return ConfiguredAction(action)
+            return ConfiguredAction(
+                action,
+                use_unique_action=self.use_unique_action,
+                parent_identifier_override=self.parent_identifier_override,
+            )
 
     def as_list(self) -> list:
         """returns a serializable list of relevant information about the configured actions"""
@@ -382,6 +466,31 @@ class ConfiguredActionList(ActionList, DumpableList):
             for action in self._action_list
         ]
 
+    def get_ca_by_action(self, action: Callable) -> Optional[ConfiguredAction]:
+        """
+        Gets the corresponding ConfiguredAction instance
+
+        :param action: gets a configured action from
+        :return:
+        """
+        for inst in self:
+            inst: ConfiguredAction
+            if inst.match_name_and_parent(action, self.parent_identifier_override):
+                return inst
+        raise NameError(f'the action {action} is not a member of the {self.__class__.__name__} instance')
+
+    def action_registered_in_list(self, action: Callable) -> bool:
+        """
+        Checks whether the provided action is the associated action of any actions registered in the Configured List
+
+        :param action: action to check against
+        """
+        try:
+            inst = self.get_ca_by_action(action)
+            return True
+        except NameError:
+            return False
+
 
 class ConfigurableInstance:
     methods_to_register: List[str] = []
