@@ -58,6 +58,11 @@ class ConfiguredDecision(ConfiguredAction):
         """
         return TrackedDecision(configuration=self, **kwargs)
 
+    def as_dict(self) -> dict:
+        dct = super(ConfiguredDecision, self).as_dict()
+        dct['logic_sequence'] = self.logic_sequence.as_list()
+        return dct
+
 
 class TrackedDecision(TrackedAction):
     UUID_PREFIX = 'da-'
@@ -123,3 +128,10 @@ class TrackedDecision(TrackedAction):
     def next_action(self) -> ConfiguredAction:
         """next action as determined by the logic tree"""
         return self._action_return
+
+    def as_dict(self) -> dict:
+        dct = super(TrackedDecision, self).as_dict()
+        if self.triggered is True:
+            dct['logic_checks'] = dct['arguments']
+            del dct['arguments']
+        return dct
