@@ -2,7 +2,7 @@
 
 from .abc import OperationalState, GenericActionState, State, StateSet
 from .component import (BadComponentState, ensure_component_online, ensure_component_inactive, ComponentState,
-                        TemporaryCallback)
+                        TemporaryOperationalCallback, TemporaryActionCallback, TemporaryCallbackSetter)
 
 
 __all__ = [
@@ -14,5 +14,7 @@ __all__ = [
     'ComponentState',
     'OperationalState',
     'GenericActionState',
-    'TemporaryCallback',
+    'TemporaryActionCallback',
+    'TemporaryCallbackSetter',
+    'TemporaryOperationalCallback',
 ]
