@@ -78,6 +78,7 @@ class TemporaryCallbackSetter(ABC):
                  callbacks: Union[Callable, Iterable[Callable]] = None,
                  threshold_state: StateSet = OperationalState.OFFLINE,
                  pre_state_change: bool = True,
+                 remove_configurations_on_exit: bool = False,
                  ):
         """
         Context manager for temporarily applying callbacks to the provided components
@@ -86,10 +87,13 @@ class TemporaryCallbackSetter(ABC):
         :param callbacks: custom callback(s) to apply
         :param threshold_state: threshold state to apply callbacks at and below
         :param pre_state_change: whether the callbacks should be added to pre- or post-state change callback lists
+        :param remove_configurations_on_exit: option to remove configurations on exit
+            (useful for one-off registered methods that will never be used again)
         """
         self.components = components
         self.threshold_state = threshold_state
         self.pre_state_change = pre_state_change
+        self.remove_on_exit = remove_configurations_on_exit
         if callbacks is None:
             callbacks = []
         elif callable(callbacks):  # cast if it's only a single callback
@@ -109,7 +113,11 @@ class TemporaryCallbackSetter(ABC):
         for component in self.components:
             for state in getattr(component, self._state_set_attribute):
                 if state <= self.threshold_state:
-                    state.deregister_callbacks(self.callback_capture, *self.callbacks)
+                    state.deregister_callbacks(self.callback_capture, remove_configurations=True)
+                    state.deregister_callbacks(
+                        *self.callbacks,
+                        remove_configurations=self.remove_on_exit,
+                    )
 
     @property
     def callback_encountered(self) -> bool:
@@ -178,6 +186,15 @@ class ComponentState(InstanceRegistry):
         self.current_action_state = current_action_state or 0
         self.logger = state_logger.getChild(self.component_name)
 
+        # set state names as parent IDs of callback list
+        for state_set in [self.operational_states, self.action_states]:
+            for state in state_set:
+                state: StateSet
+                if isinstance(state.value, State):
+                    # set parent identifier override to be the string of the state
+                    state.value.pre_state_callbacks.parent_identifier_override = state.__class__.__name__
+                    state.value.post_state_callbacks.parent_identifier_override = state.__class__.__name__
+
     @staticmethod
     def _match_instance_key(inst: "ComponentState", identifier: str) -> bool:
         """matches the provided identifier against the component name and standard identifiers"""
