@@ -198,6 +198,13 @@ class TestStates(unittest.TestCase):
     def setUpClass(cls) -> None:
         cls.test_state_one = State(1)
 
+    def test_meaning(self):
+        """tests meaning setting of the State class"""
+        string = 'test meaning string (docstring) for the state'
+        state = State(1, meaning=string)
+        self.assertTrue(hasattr(state, 'meaning'), 'ensure that a meaning was assigned')
+        self.assertEqual(state.meaning, string, 'check that the state was correctly assigned')
+
     def test_comparisons(self):
         """tests integer state comparisons"""
         self.assertTrue(1 == self.test_state_one, 'check eq')
